@@ -7,9 +7,12 @@ from .asserts import *
 from .constants import *
 from .norm_func import *
 from .normalise_func import *
+from .mosaic_func import *
+from .loss_func import *
+from .discretise_func import *
 from .perturb_func import *
 from .plotting import *
-from .similar_func import *
+from .similarity_func import *
 from .utils import *
 from .warn_func import *
 
