@@ -1,17 +1,29 @@
 from abc import ABC, abstractmethod
-from typing import Optional, Tuple
+from typing import Any, Dict, Optional, Tuple
 import numpy as np
 
 
 class ModelInterface(ABC):
     """Interface for torch and tensorflow models."""
 
-    def __init__(self, model, channel_first=True):
+    def __init__(
+        self,
+        model,
+        channel_first: bool = True,
+        softmax: bool = False,
+        predict_kwargs: Optional[Dict[str, Any]] = None,
+    ):
         self.model = model
         self.channel_first = channel_first
+        self.softmax = softmax
+
+        if predict_kwargs is None:
+            self.predict_kwargs = {}
+        else:
+            self.predict_kwargs = predict_kwargs
 
     @abstractmethod
-    def predict(self, x_input):
+    def predict(self, x, **kwargs):
         """Predict on the given input."""
         raise NotImplementedError
 
