@@ -2,6 +2,7 @@
 from importlib import util
 
 # Import different models depending on which deep learning framework is installed.
+from typing import Tuple
 
 if util.find_spec("torch"):
 
@@ -10,7 +11,9 @@ if util.find_spec("torch"):
     class LeNet(torch.nn.Module):
         """Network architecture from: https://github.com/ChawDoe/LeNet5-MNIST-PyTorch."""
 
-        def __init__(self):
+        def __init__(
+            self,
+        ):
             super().__init__()
             self.conv_1 = torch.nn.Conv2d(1, 6, 5)
             self.pool_1 = torch.nn.MaxPool2d(2, 2)
@@ -33,6 +36,46 @@ if util.find_spec("torch"):
             x = self.fc_3(x)
             return x
 
+    class LeNetAdaptivePooling(torch.nn.Module):
+        """Network architecture from with adaptive pooling: https://github.com/ChawDoe/LeNet5-MNIST-PyTorch."""
+
+        @staticmethod
+        def _eval_adaptive_size(input_size: int) -> int:
+            conv1_output_size = (input_size - 5 + 1) // 2
+            conv2_output_size = (conv1_output_size - 5 + 1) // 2
+            return conv2_output_size
+
+        def __init__(self, input_shape: Tuple[int, int, int]):
+            super().__init__()
+            n_channels = input_shape[0]
+            adaptive_width = self._eval_adaptive_size(input_shape[1])
+            adaptive_height = self._eval_adaptive_size(input_shape[2])
+            adaptive_shape = (adaptive_width, adaptive_height)
+            n_fc_input = adaptive_width * adaptive_height * 16
+
+            self.conv_1 = torch.nn.Conv2d(n_channels, 6, 5)
+            self.pool_1 = torch.nn.MaxPool2d(2, 2)
+            self.relu_1 = torch.nn.ReLU()
+            self.conv_2 = torch.nn.Conv2d(6, 16, 5)
+            self.pool_2 = torch.nn.MaxPool2d(2, 2)
+            self.relu_2 = torch.nn.ReLU()
+            self.avg_pooling = torch.nn.AdaptiveAvgPool2d(adaptive_shape)
+            self.fc_1 = torch.nn.Linear(n_fc_input, 120)
+            self.relu_3 = torch.nn.ReLU()
+            self.fc_2 = torch.nn.Linear(120, 84)
+            self.relu_4 = torch.nn.ReLU()
+            self.fc_3 = torch.nn.Linear(84, 10)
+
+        def forward(self, x):
+            x = self.pool_1(self.relu_1(self.conv_1(x)))
+            x = self.pool_2(self.relu_2(self.conv_2(x)))
+            x = self.avg_pooling(x)
+            x = x.view(x.shape[0], -1)
+            x = self.relu_3(self.fc_1(x))
+            x = self.relu_4(self.fc_2(x))
+            x = self.fc_3(x)
+            return x
+
     class ConvNet1D(torch.nn.Module):
         """1D-convolutional architecture inspired from LeNet."""
 
@@ -45,7 +88,7 @@ if util.find_spec("torch"):
             self.pool_2 = torch.nn.MaxPool1d(2, 2)
             self.relu_2 = torch.nn.ReLU()
 
-            # TODO: use closed formula or use LazyLinear layers
+            # TODO: Use closed formula or use LazyLinear layers.
             if n_channels == 1:
                 n_fc_input = 64
             elif n_channels == 3:
