@@ -4,6 +4,8 @@ import numpy as np
 import matplotlib.pyplot as plt
 from skimage.segmentation import *
 
+from . import warn_func
+
 
 def plot_pixel_flipping_experiment(
     y_batch: np.ndarray,
@@ -54,14 +56,18 @@ def plot_selectivity_experiment(
     """
     fig = plt.figure(figsize=(8, 6))
     if isinstance(results, dict):
+        alllengths = [len(score) for scores in results.values() for score in scores]
+        minlength = np.min(alllengths)
+        if np.any(np.array(alllengths) > minlength):
+            warn_func.warn_different_array_lengths()
         for method, scores in results.items():
             plt.plot(
-                np.arange(0, len(scores[0])),
-                np.mean(np.array(list(scores.values())), axis=0),
-                label=f"{str(method.capitalize())} ({len(list(scores))} samples)",
+                np.arange(0, len(scores[0][:minlength])),
+                np.mean(np.array([score[:minlength] for score in scores]), axis=0),
+                label=f"{str(method.capitalize())}",
             )
     elif isinstance(results, list):
-        pass
+        plt.plot(np.arange(0, len(results)), np.mean(results, axis=0))
     plt.xlabel(f"# Patches removed")
     plt.ylabel(f"Average function value $f(x)$")
     plt.gca().set_yticklabels(
@@ -84,10 +90,14 @@ def plot_region_perturbation_experiment(
     """
     fig = plt.figure(figsize=(8, 6))
     if isinstance(results, dict):
+        alllengths = [len(score) for scores in results.values() for score in scores]
+        minlength = np.min(alllengths)
+        if np.any(np.array(alllengths) > minlength):
+            warn_func.warn_different_array_lengths()
         for method, scores in results.items():
             plt.plot(
-                np.arange(0, len(scores[0])),
-                np.mean(np.array(list(scores.values())), axis=0),
+                np.arange(0, len(scores[0][:minlength])),
+                np.mean(np.array([score[:minlength] for score in scores]), axis=0),
                 label=f"{str(method.capitalize())}",
             )
     else:
@@ -116,8 +126,8 @@ def plot_sensitivity_n_experiment(
     if isinstance(results, dict):
         for method, scores in results.items():
             plt.plot(
-                np.linspace(0, 1, len(scores[0])),
-                np.mean(np.array(list(scores.values())), axis=0),
+                np.arange(0, len(scores)),
+                scores,
                 label=f"{str(method.capitalize())}",
             )
     else:
@@ -192,3 +202,28 @@ def plot_model_parameter_randomisation_experiment(
     if methods:
         plt.legend(methods)
     plt.show()
+
+
+def plot_focus(
+    results: Dict[str, List[float]],
+) -> None:
+    """
+    Plot the Focus scores of different methods in a box plot like manner as done in the original paper:
+     References:
+        1) "Arias-Duart, Anna, et al. 'Focus! Rating XAI Methods and Finding Biases. arXiv:2109.15035 (2022)"
+
+    Parameters
+    ----------
+        results: a dictionary with the Focus scores obtained using different feature attribution methods. The keys
+                 of the dict must be strings referring to the feature attribution method and values should be a
+                 list of floats corresponding to the Focus scores.
+    """
+
+    fig = plt.figure(figsize=(8, 6))
+    for method, scores in results.items():
+        plt.boxplot(scores)
+        plt.xlabel(method)
+
+    plt.ylabel("Focus score")
+    plt.tick_params(axis="x", which="both", bottom=False, top=False, labelbottom=False)
+    plt.show()
