@@ -1,7 +1,7 @@
 """This model creates the ModelInterface for PyTorch."""
 from contextlib import suppress
 from copy import deepcopy
-from typing import Optional, Tuple
+from typing import Any, Dict, Optional, Tuple
 
 import torch
 import numpy as np
@@ -13,37 +13,60 @@ from ..helpers import utils
 class PyTorchModel(ModelInterface):
     """Interface for torch models."""
 
-    def __init__(self, model, channel_first):
-        super().__init__(model, channel_first)
+    def __init__(
+        self,
+        model,
+        channel_first: bool = True,
+        softmax: bool = False,
+        device: Optional[str] = None,
+        predict_kwargs: Optional[Dict[str, Any]] = None,
+    ):
+        super().__init__(
+            model=model,
+            channel_first=channel_first,
+            softmax=softmax,
+            predict_kwargs=predict_kwargs,
+        )
+        self.device = device
 
-    def predict(self, x, **kwargs):
+    def predict(self, x: np.ndarray, grad: bool = False, **kwargs):
         """Predict on the given input."""
+
+        # Use kwargs of predict call if specified, but don't overwrite object attribute
+        predict_kwargs = {**self.predict_kwargs, **kwargs}
+
         if self.model.training:
             raise AttributeError("Torch model needs to be in the evaluation mode.")
 
-        softmax = kwargs.get("softmax", False)
-        device = kwargs.get("device", None)
-        grad = kwargs.get("grad", False)
         grad_context = torch.no_grad() if not grad else suppress()
 
         with grad_context:
-            pred = self.model(torch.Tensor(x).to(device))
-            if softmax:
+            pred = self.model(torch.Tensor(x).to(self.device), **predict_kwargs)
+            if self.softmax:
                 pred = torch.nn.Softmax(dim=-1)(pred)
             if pred.requires_grad:
                 return pred.detach().cpu().numpy()
             return pred.cpu().numpy()
 
     def shape_input(
-        self, x: np.array, shape: Tuple[int, ...], channel_first: Optional[bool] = None
+        self,
+        x: np.array,
+        shape: Tuple[int, ...],
+        channel_first: Optional[bool] = None,
+        batched: bool = False,
     ):
         """
         Reshape input into model expected input.
         channel_first: Explicitely state if x is formatted channel first (optional).
         """
         if channel_first is None:
-            channel_first = utils.infer_channel_first
-        x = x.reshape(1, *shape)
+            channel_first = utils.infer_channel_first(x)
+
+        # Expand first dimension if this is just a single instance.
+        if not batched:
+            x = x.reshape(1, *shape)
+
+        # Set channel order according to expected input of model.
         if self.channel_first:
             return utils.make_channel_first(x, channel_first)
         raise ValueError("Channel first order expected for a torch model.")
@@ -80,3 +103,29 @@ class PyTorchModel(ModelInterface):
             torch.manual_seed(seed=seed + 1)
             module[1].reset_parameters()
             yield module[0], random_layer_model
+
+    def sample(
+            self,
+            mean: float,
+            std: float,
+            noise_type: str = "multiplicative",
+    ):
+        """Sample a model by means of adding noise."""
+
+        distribution = torch.distributions.normal.Normal(loc=mean, scale=std)
+        original_parameters = self.state_dict()
+        model_copy = deepcopy(self.model)
+        model_copy.load_state_dict(original_parameters)
+
+        # If std is not zero, loop over each layer and add Gaussian noise.
+        if not std == 0.0:
+            with torch.no_grad():
+                for layer in model_copy.parameters():
+                    if noise_type == "additive":
+                        layer.add_(distribution.sample(layer.size()).to(layer.device))
+                    elif noise_type == "multiplicative":
+                        layer.mul_(distribution.sample(layer.size()).to(layer.device))
+                    else:
+                        raise ValueError("Set noise_type to either 'multiplicative' "
+                                         "or 'additive' (str) when you sample the model.")
+        return model_copy
\ No newline at end of file
