@@ -2,7 +2,7 @@
 import re
 import copy
 import numpy as np
-from typing import Callable, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 from importlib import util
 from skimage.segmentation import slic, felzenszwalb
 from ..helpers.model_interface import ModelInterface
@@ -17,7 +17,15 @@ if util.find_spec("tensorflow"):
 
 
 def get_superpixel_segments(img: np.ndarray, segmentation_method: str) -> np.ndarray:
-    """Given an image, return segments or so-called 'super-pixels' segments i.e., an 2D mask with segment labels."""
+    """
+    Given an image, return segments or so-called 'super-pixels' segments i.e., an 2D mask with segment labels.
+
+    Parameters
+    ----------
+
+    Returns
+
+    """
     if img.ndim != 3:
         raise ValueError(
             "Make sure that x is 3 dimensional e.g., (3, 224, 224) to calculate super-pixels."
@@ -43,8 +51,15 @@ def get_baseline_value(
     patch: Optional[np.ndarray] = None,
     **kwargs,
 ) -> np.array:
-    """Get the baseline value to fill the array with, in the shape of return_shape"""
+    """
+    Get the baseline value to fill the array with, in the shape of return_shape.
 
+    Parameters
+    ----------
+
+    Returns
+    """
+    kwargs["return_shape"] = return_shape
     if isinstance(value, (float, int)):
         return np.full(return_shape, value)
     elif isinstance(value, np.ndarray):
@@ -77,13 +92,20 @@ def get_baseline_value(
 def get_baseline_dict(
     arr: np.ndarray, patch: Optional[np.ndarray] = None, **kwargs
 ) -> dict:
-    """Make a dicionary of baseline approaches depending on the input x (or patch of input)."""
+    """
+    Make a dicionary of baseline approaches depending on the input x (or patch of input).
+
+    Parameters
+    ----------
+
+    Returns
+    """
     fill_dict = {
         "mean": float(arr.mean()),
-        "uniform": float(
-            np.random.uniform(
-                low=kwargs.get("uniform_low", 0.0), high=kwargs.get("uniform_high", 1.0)
-            )
+        "uniform": np.random.uniform(
+            low=kwargs.get("uniform_low", 0.0),
+            high=kwargs.get("uniform_high", 1.0),
+            size=kwargs["return_shape"],
         ),
         "black": float(arr.min()),
         "white": float(arr.max()),
@@ -161,7 +183,14 @@ def infer_channel_first(x: np.array):
 
 
 def make_channel_first(x: np.array, channel_first=False):
-    """Reshape batch to channel first."""
+    """
+    Reshape batch to channel first.
+
+    Parameters
+    ----------
+
+    Returns
+    """
     if channel_first:
         return x
 
@@ -190,17 +219,41 @@ def make_channel_last(x: np.array, channel_first=True):
         )
 
 
-def get_wrapped_model(model: ModelInterface, channel_first: bool) -> ModelInterface:
+def get_wrapped_model(
+    model,
+    channel_first: bool,
+    softmax: bool,
+    device: Optional[str] = None,
+    predict_kwargs: Optional[Dict[str, Any]] = None,
+) -> ModelInterface:
     """
     Identifies the type of a model object and wraps the model in an appropriate interface.
 
+    Parameters
+    ----------
+    model: a pytorch or tensorflow model that is to be wrapped.
+    channel_first (boolean): Indicates if model expects channel first or channel last layout.
+    predict_kwargs (dict, optional): Keyword arguments to be passed to the model's predict method, default = {}
+
     Returns
-        A wrapped ModelInterface model.
+    -------
+    model (ModelInterface): A wrapped ModelInterface model.
     """
     if isinstance(model, tf.keras.Model):
-        return TensorFlowModel(model, channel_first)
+        return TensorFlowModel(
+            model=model,
+            channel_first=channel_first,
+            softmax=softmax,
+            predict_kwargs=predict_kwargs,
+        )
     if isinstance(model, torch.nn.modules.module.Module):
-        return PyTorchModel(model, channel_first)
+        return PyTorchModel(
+            model=model,
+            channel_first=channel_first,
+            softmax=softmax,
+            device=device,
+            predict_kwargs=predict_kwargs,
+        )
     raise ValueError(
         "Model needs to be tf.keras.Model or torch.nn.modules.module.Module."
     )
@@ -213,7 +266,11 @@ def blur_at_indices(
     indexed_axes: Sequence[int],
 ) -> np.array:
     """
-    Returns a version of arr that is blurred at indices
+    Returns a version of arr that is blurred at indices.
+
+    Parameters
+    ----------
+
     """
 
     assert kernel.ndim == len(
@@ -236,7 +293,7 @@ def blur_at_indices(
         if isinstance(idx, slice) and idx == slice(None):
             none_slices.append(idx)
         elif isinstance(idx, np.ndarray):
-            pad_left = kernel.shape[indexed_axes.index(i)] // 2
+            pad_left = kernel.shape[[p for p in indexed_axes].index(i)] // 2
             array_indices.append(idx + pad_left)
         else:
             raise ValueError("Invalid indices {}".format(indices))
@@ -279,6 +336,10 @@ def create_patch_slice(
 ) -> Tuple[np.ndarray]:
     """
     Create a patch slice from patch size and coordinates.
+
+    Parameters
+    ----------
+
     """
 
     if isinstance(patch_size, int):
@@ -301,10 +362,11 @@ def create_patch_slice(
     # make sure that each element in tuple is integer
     patch_size = tuple(int(patch_size_dim) for patch_size_dim in patch_size)
 
-    patch_slice = [
+    gridcoords = [
         np.arange(coord, coord + patch_size_dim)
         for coord, patch_size_dim in zip(coords, patch_size)
     ]
+    patch_slice = np.meshgrid(*gridcoords)
 
     return tuple(patch_slice)
 
@@ -312,7 +374,12 @@ def create_patch_slice(
 def get_nr_patches(
     patch_size: Union[int, Sequence[int]], shape: Tuple[int, ...], overlap: bool = False
 ) -> int:
-    """Get number of patches for given shape."""
+    """
+    Get number of patches for given shape.
+
+    Parameters
+    ----------
+    """
     if isinstance(patch_size, int):
         patch_size = (patch_size,)
     patch_size = np.array(patch_size)
@@ -337,7 +404,12 @@ def _pad_array(
     mode: str,
     padded_axes: Sequence[int],
 ):
-    """To allow for any patch_size we add padding to the array."""
+    """
+    To allow for any patch_size we add padding to the array.
+
+    Parameters
+    ----------
+    """
 
     assert (
         len(padded_axes) <= arr.ndim
@@ -357,12 +429,15 @@ def _pad_array(
             pad_width_list.append((0, 0))
         elif isinstance(pad_width, int):
             pad_width_list.append((pad_width, pad_width))
-        elif isinstance(pad_width[padded_axes.index(ax)], int):
+        elif isinstance(pad_width[[p for p in padded_axes].index(ax)], int):
             pad_width_list.append(
-                (pad_width[padded_axes.index(ax)], pad_width[padded_axes.index(ax)])
+                (
+                    pad_width[[p for p in padded_axes].index(ax)],
+                    pad_width[[p for p in padded_axes].index(ax)],
+                )
             )
         else:
-            pad_width_list.append(pad_width[padded_axes.index(ax)])
+            pad_width_list.append(pad_width[[p for p in padded_axes].index(ax)])
     arr_pad = np.pad(arr, pad_width_list, mode=mode)
     return arr_pad
 
@@ -372,7 +447,19 @@ def _unpad_array(
     pad_width: Union[int, Sequence[int], Sequence[Tuple[int]]],
     padded_axes: Sequence[int],
 ):
-    """Remove padding from the array."""
+    """
+    Remove padding from the array.
+
+    Parameters
+    ----------
+        arr: a numpy array of the input to be unpaded
+        pad_witdh: the width of the padding for the different dimensions
+        padded_axes: the axes for padding
+
+    Returns
+        the unpadded array
+
+    """
 
     assert (
         len(padded_axes) <= arr.ndim
@@ -392,25 +479,32 @@ def _unpad_array(
             unpad_slice.append(slice(None))
         elif isinstance(pad_width, int):
             unpad_slice.append(slice(pad_width, arr.shape[ax] - pad_width))
-        elif isinstance(pad_width[padded_axes.index(ax)], int):
+        elif isinstance(pad_width[[p for p in padded_axes].index(ax)], int):
             unpad_slice.append(
                 slice(
-                    pad_width[padded_axes.index(ax)],
-                    arr.shape[ax] - pad_width[padded_axes.index(ax)],
+                    pad_width[[p for p in padded_axes].index(ax)],
+                    arr.shape[ax] - pad_width[[p for p in padded_axes].index(ax)],
                 )
             )
         else:
             unpad_slice.append(
                 slice(
-                    pad_width[padded_axes.index(ax)][0],
-                    arr.shape[ax] - pad_width[padded_axes.index(ax)][1],
+                    pad_width[[p for p in padded_axes].index(ax)][0],
+                    arr.shape[ax] - pad_width[[p for p in padded_axes].index(ax)][1],
                 )
             )
     return arr[tuple(unpad_slice)]
 
 
 def expand_attribution_channel(a_batch: np.ndarray, x_batch: np.ndarray):
-    """Expand additional channel dimension(s) for attributions if needed."""
+    """
+    Expand additional channel dimension(s) for attributions if needed.
+
+    Parameters
+    ----------
+        x_batch: a np.ndarray which contains the input data that are explained
+        a_batch: a Union[np.ndarray, None] which contains pre-computed attributions i.e., explanations
+    """
     if a_batch.shape[0] != x_batch.shape[0]:
         raise ValueError(
             f"a_batch and x_batch must have same number of batches ({a_batch.shape[0]} != {x_batch.shape[0]})"
@@ -425,18 +519,27 @@ def expand_attribution_channel(a_batch: np.ndarray, x_batch: np.ndarray):
     else:
         attr_axes = infer_attribution_axes(a_batch, x_batch)
 
-        # TODO: infer_attribution_axes currently returns dimensions w/o batch dimension
+        # TODO: Infer_attribution_axes currently returns dimensions w/o batch dimension.
         attr_axes = [a + 1 for a in attr_axes]
         expand_axes = [a for a in range(1, x_batch.ndim) if a not in attr_axes]
 
         return np.expand_dims(a_batch, axis=tuple(expand_axes))
 
 
-# TODO: adapt for batched processing
 def infer_attribution_axes(a_batch: np.ndarray, x_batch: np.ndarray) -> Sequence[int]:
     """
     Infers the axes in x_batch that are covered by a_batch.
+
+    Parameters
+    ----------
+        x_batch: a np.ndarray which contains the input data that are explained
+        a_batch: a Union[np.ndarray, None] which contains pre-computed attributions i.e., explanations
+
+    Returns
+        the axes inferred
     """
+    # TODO: Adapt for batched processing.
+
     if a_batch.shape[0] != x_batch.shape[0]:
         raise ValueError(
             f"a_batch and x_batch must have same number of batches ({a_batch.shape[0]} != {x_batch.shape[0]})"
@@ -449,7 +552,7 @@ def infer_attribution_axes(a_batch: np.ndarray, x_batch: np.ndarray) -> Sequence
             )
         )
 
-    # TODO: we currently assume here that the batch axis is not carried into the perturbation functions
+    # TODO: We currently assume here that the batch axis is not carried into the perturbation functions.
     a_shape = [s for s in np.shape(a_batch)[1:] if s != 1]
     x_shape = [s for s in np.shape(x_batch)[1:]]
 
@@ -465,6 +568,7 @@ def infer_attribution_axes(a_batch: np.ndarray, x_batch: np.ndarray) -> Sequence
         for start in range(0, len(x_shape) - len(a_shape) + 1)
     ]
     if x_subshapes.count(a_shape) < 1:
+
         # Check that attribution dimensions are (consecutive) subdimensions of inputs
         raise ValueError(
             "Attribution dimensions are not (consecutive) subdimensions of inputs:  "
@@ -473,15 +577,18 @@ def infer_attribution_axes(a_batch: np.ndarray, x_batch: np.ndarray) -> Sequence
             )
         )
     elif x_subshapes.count(a_shape) > 1:
+
         # Check that attribution dimensions are (unique) subdimensions of inputs.
         # Consider potentially expanded dims in attributions.
+
         if a_batch.ndim == x_batch.ndim and len(a_shape) < a_batch.ndim:
             a_subshapes = [
                 [np.shape(a_batch)[1:][i] for i in range(start, start + len(a_shape))]
                 for start in range(0, len(np.shape(a_batch)[1:]) - len(a_shape) + 1)
             ]
             if a_subshapes.count(a_shape) == 1:
-                # Inferring channel shape
+
+                # Inferring channel shape.
                 for dim in range(len(np.shape(a_batch)[1:]) + 1):
                     if a_shape == np.shape(a_batch)[1:][dim:]:
                         return np.arange(dim, len(np.shape(a_batch)[1:]))
@@ -503,7 +610,7 @@ def infer_attribution_axes(a_batch: np.ndarray, x_batch: np.ndarray) -> Sequence
             )
         )
     else:
-        # Infer attribution axes
+        # Infer attribution axes.
         for dim in range(len(x_shape) + 1):
             if a_shape == x_shape[dim:]:
                 return np.arange(dim, len(x_shape))
@@ -516,7 +623,6 @@ def infer_attribution_axes(a_batch: np.ndarray, x_batch: np.ndarray) -> Sequence
     )
 
 
-# TODO: adapt for batched processing (if necessary)
 def expand_indices(
     arr: np.array,
     indices: Union[int, Sequence[int], Tuple[np.array], Tuple[slice]],
@@ -525,14 +631,22 @@ def expand_indices(
     """
     Expands indices to fit array shape. Returns expanded indices.
 
-    indexed_axes refers to all axes that are not indexed by slice(None).
-    """
+    Parameters
+    ----------
+        arr: the input to the expanded
+        indicies: list of indicies
+        indexed_axes: refers to all axes that are not indexed by slice(None).
 
-    # Handle indexed_axes
+    Returns
+
+    """
+    # TODO: Adapt for batched processing.
+
+    # Handle indexed_axes.
     indexed_axes = np.sort(np.array(indexed_axes))
     asserts.assert_indexed_axes(arr, indexed_axes)
 
-    # Handle indices
+    # Handle indices.
     if isinstance(indices, int):
         expanded_indices = [indices]
     else:
@@ -551,33 +665,33 @@ def expand_indices(
                 try:
                     expanded_indices.append(int(idx))
                 except:
-                    raise ValueError("Unsupported type of indices")
+                    raise ValueError("Unsupported type of indices.")
 
-    # Check if unraveling is needed
+    # Check if unraveling is needed.
     if np.all([isinstance(i, int) for i in expanded_indices]):
         expanded_indices = np.unravel_index(
             expanded_indices, tuple([arr.shape[i] for i in indexed_axes])
         )
 
-    # Handle case of 1D indices
+    # Handle case of 1D indices.
     if not np.array(expanded_indices).ndim > 1:
         expanded_indices = [np.array(expanded_indices)]
 
-    # Cast to list so item assignment works
+    # Cast to list so item assignment works.
     expanded_indices = list(expanded_indices)
 
     if indexed_axes.size != len(expanded_indices):
         raise ValueError("indices dimension doesn't match indexed_axes")
 
     # Ensure array dimensions are kept when indexing.
-    # Expands dimensions of each element in expanded_indices depending on the number of elements
+    # Expands dimensions of each element in expanded_indices depending on the number of elements.
     for i in range(len(expanded_indices)):
         if expanded_indices[i].ndim != len(expanded_indices):
             expanded_indices[i] = np.expand_dims(
                 expanded_indices[i], axis=tuple(range(len(expanded_indices) - 1))
             )
 
-    # Buffer with None-slices if indices index the last axes
+    # Buffer with None-slices if indices index the last axes.
     for i in range(0, indexed_axes[0]):
         expanded_indices = slice(None), *expanded_indices
 
@@ -586,9 +700,18 @@ def expand_indices(
 
 def get_leftover_shape(arr: np.array, axes: Sequence[int]) -> Tuple:
     """
-    Gets the shape of the arr dimensions not included in axes
+    Gets the shape of the arr dimensions not included in axes.
+
+    Parameters
+    ----------
+        arr: the input to the expanded
+        axes: a sequence of ints containing the axes
+
+    Returns
+        a tuple of the leftover shape
     """
-    # TODO: adapt for batched processing (if necessary).
+
+    # TODO: Adapt for batched processing.
     axes = np.sort(np.array(axes))
     asserts.assert_indexed_axes(arr, axes)
 
@@ -598,12 +721,17 @@ def get_leftover_shape(arr: np.array, axes: Sequence[int]) -> Tuple:
 
 def offset_coordinates(indices: list, offset: tuple, img_shape: tuple):
     """
-    Checks if offset coordinates are within the image frame. Return offset coordinates for valid indices and the
-    list of booleans which identifies valid ids.
+    Checks if offset coordinates are within the image frame
     Based on https://github.com/tleemann/road_evaluation.
-    indices (list): list of indices to be offset.
-    offset (tuple): offset for the coordinates, e.g. offset (1,1) adds 1 to both coordinates.
-    img_shape (tuple): image shape in (channels, height, width) format.
+      Parameters
+    ----------
+        a tuple of the leftover shape
+        indices (list): list of indices to be offset.
+        offset (tuple): offset for the coordinates, e.g. offset (1,1) adds 1 to both coordinates.
+        img_shape (tuple): image shape in (channels, height, width) format.
+
+    Returns
+         offset coordinates for valid indices and the list of booleans which identifies valid ids.
     """
     x = indices // img_shape[2]
     y = indices % img_shape[2]
@@ -613,6 +741,7 @@ def offset_coordinates(indices: list, offset: tuple, img_shape: tuple):
     off_coords = indices + offset[0] * img_shape[2] + offset[1]
     return off_coords[valid], valid
 
-  
-def calculate_auc(i: np.array, dx: int = 1.0):
-    return np.trapz(np.array(i), dx=dx)
+
+def calculate_auc(values: np.array, dx: int = 1.0):
+    """Calculate area under the curve using the composite trapezoidal rule."""
+    return np.trapz(np.array(values), dx=dx)
